@@ -232,4 +232,4 @@ def _reader_thread(task, consumer, queue):
 def ensure_str(s):
     if isinstance(s, unicode):
         return s.encode('utf-8')
-    return s
\ No newline at end of file
+    return str(s)
\ No newline at end of file
